@@ -10,11 +10,10 @@ package Devel::Cover::Op;
 use strict;
 use warnings;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
-use Devel::Cover qw(-inc B -indent 1 -details 1);
-
-my @Options;
+use Devel::Cover qw( -inc B -indent 1 -details 1 );
+use B::Concise   qw( set_style add_callback );
 
 my %style =
   ("terse" =>
@@ -37,32 +36,30 @@ my %style =
     "#addr"],
   );
 
-sub set_style
-{
-    my ($style) = @_;
-    @ENV{qw(B_CONCISE_FORMAT B_CONCISE_GOTO_FORMAT B_CONCISE_TREE_FORMAT)} =
-        @{$style{$style}};
-}
+my @Options;
 
 sub import
 {
     my $class = shift;
-    @Options = ("-env");
-    set_style("concise");
+    set_style(@{$style{concise}});
     for (@_)
     {
         /-(.*)/ && exists $style{$1}
-            ? set_style($1)
+            ? set_style(@{$style{$1}})
             : push @Options, $_;
     }
-    $ENV{B_CONCISE_SUB} = "Devel::Cover::Op::concise_op";
+    add_callback
+    (
+        sub
+        {
+            my ($h, $op, $level, $format) = @_;
+            $h->{cover} = Devel::Cover::coverage()->{pack "I*", $$op} ||
+                         ($h->{seq} ? "-" : "");
+        }
+    );
+
 }
 
-END { require B::Concise; B::Concise::compile(@Options)->() }
+END { B::Concise::compile(@Options)->() }
 
-sub concise_op
-{
-    my ($h, $op, $level, $format) = @_;
-    $h->{cover} = Devel::Cover::coverage()->{pack "I*", $$op} ||
-                 ($h->{seq} ? "-" : "");
-}
+1;
